<?php


namespace app\api\controller;


use Endroid\QrCode\Builder\Builder;
use Endroid\QrCode\ErrorCorrectionLevel\ErrorCorrectionLevelHigh;
use Endroid\QrCode\Label\Alignment\LabelAlignmentCenter;
use Endroid\QrCode\Label\Font\NotoSans;
use Endroid\QrCode\Writer\PngWriter;
use think\facade\Log;
use ZxingSPE\QrReader;

class Qrcode extends Base
{
    /**
     * 在线生成二维码
     * 示例：https://api.ycxxkj.com/index.php/api/qrcode/online/text/WT202410012092476944/size/500/label/WT202410012092476944/lable_size/100
     * @return \think\Response
     */
    public function online()
    {
        $param = input("param.");
        $rules = [
            "text" => "require",
            "size" => "number|between:100,1000",
        ];
        $this->autoValid($rules, $param);
        $text = urldecode2(input("text"));
        $size = input("size", 300);
        $label = urldecode2(input("label", ""));
        $labelSize = input("lable_size", 44);
        if ($text) {
            $text = urldecode2($text);
        }
        if ($label) {
            $label = urldecode2($label);
        }
        //二维码生成的包：https://packagist.org/packages/endroid/qr-code
        $result = Builder::create()->writer(new PngWriter())->data($text)
            ->errorCorrectionLevel(new ErrorCorrectionLevelHigh())
            ->labelText($label)
            ->labelAlignment(new LabelAlignmentCenter())
            ->labelFont(new NotoSans($labelSize))
            ->size($size)
            ->build();
        return response($result->getString(), 200)->contentType($result->getMimeType());
    }

    /**
     * 识别图片二维码
     * @return void
     * @throws \Exception
     */
    public function read()
    {
        $url = input("url", "");
        if (!$url) {
            $this->error("url为空");
        }
        $qrcodeReader = new QrReader($url);
        $qrcodeText = $qrcodeReader->text();
        $this->success(["text" => $qrcodeText]);
    }
}